@@ -45,9 +45,9 @@
 #'  If \code{alpha_start} takes a scalar value, then that value will serve for all of the \eqn{\alpha} parameters.
 #' @param V_alpha Starting value for variance of random site effect if \code{site_effect="random"} or constant variance of the Gaussian prior distribution for the fixed site effect if 
 #' \code{site_effect="fixed"}. Must be a strictly positive scalar, ignored if \code{site_effect="none"}.
-#' @param shape Shape parameter of the Inverse-Gamma prior for the random site effect variance \code{V_alpha}, ignored if \code{site_effect="none"} or \code{site_effect="fixed"}. 
+#' @param shape_Valpha Shape parameter of the Inverse-Gamma prior for the random site effect variance \code{V_alpha}, ignored if \code{site_effect="none"} or \code{site_effect="fixed"}. 
 #' Must be a strictly positive scalar. Default to 0.5 for weak informative prior.
-#' @param rate Rate parameter of the Inverse-Gamma prior for the random site effect variance \code{V_alpha}, ignored if \code{site_effect="none"} or \code{site_effect="fixed"}
+#' @param rate_Valpha Rate parameter of the Inverse-Gamma prior for the random site effect variance \code{V_alpha}, ignored if \code{site_effect="none"} or \code{site_effect="fixed"}
 #' Must be a strictly positive scalar. Default to 0.0005 for weak informative prior.
 #' @param mu_beta Means of the Normal priors for the \eqn{\beta}{\beta} parameters of the suitability process. \code{mu_beta} must be either a scalar or a \eqn{np}-length vector.
 #'  If \code{mu_beta} takes a scalar value, then that value will serve as the prior mean for all of the \eqn{\beta} parameters.
@@ -202,8 +202,8 @@
 #'   alpha_start=0,
 #'   V_alpha=1,
 #'   # Priors
-#'   shape=0.5,
-#'   rate=0.0005,
+#'   shape_Valpha=0.5,
+#'   rate_Valpha=0.0005,
 #'   mu_beta=0,
 #'   V_beta=10,
 #'   mu_lambda=0,
@@ -335,7 +335,7 @@ jSDM_binomial_logit <- function(# Iteration
                                 alpha_start=0, 
                                 V_alpha=1,
                                 # Priors 
-                                shape=0.5, rate=0.0005,
+                                shape_Valpha=0.5, rate_Valpha=0.0005,
                                 mu_beta=0, V_beta=10,
                                 mu_gamma=0, V_gamma=10, 
                                 mu_lambda=0, V_lambda=10,
@@ -452,7 +452,7 @@ jSDM_binomial_logit <- function(# Iteration
       
       # Form and check priors
       mubeta <- check.mubeta(mu_beta,np)
-      Vbeta <- check.Vbeta(V_beta,np)
+      V_beta <- check.Vbeta(V_beta,np)
       mulambda <- check.mubeta(mu_lambda,n_latent)
       Vlambda <- check.Vlambda(V_lambda,n_latent)
       V_W <- rep(1,n_latent)
@@ -460,7 +460,7 @@ jSDM_binomial_logit <- function(# Iteration
       # call Rcpp function
       mod <- Rcpp_jSDM_binomial_logit_lv(ngibbs=ngibbs, nthin=nthin, nburn=nburn,
                                          Y=Y,T=T, X=as.matrix(X),
-                                         beta_start=beta_start, mu_beta = mubeta, V_beta=Vbeta,
+                                         beta_start=beta_start, mu_beta = mubeta, V_beta=V_beta,
                                          lambda_start=lambda_start, mu_lambda = mulambda, V_lambda=Vlambda,
                                          W_start = W_start, V_W = V_W,
                                          ropt=ropt, seed=seed, verbose=verbose)
@@ -493,7 +493,7 @@ jSDM_binomial_logit <- function(# Iteration
                          presence_data=Y, trials=T, 
                          site_formula=site_formula,
                          site_data=site_data, n_latent=n_latent,
-                         beta_start=beta_start, mu_beta=mubeta, V_beta=Vbeta,
+                         beta_start=beta_start, mu_beta=mubeta, V_beta=V_beta,
                          lambda_start=lambda_start, mu_lambda=mulambda, V_lambda=Vlambda,
                          W_start=W_start, V_W=V_W,
                          site_effect=site_effect, family="binomial", link="logit",
@@ -523,14 +523,15 @@ jSDM_binomial_logit <- function(# Iteration
       
       # Form and check priors
       mubeta <- check.mubeta(mu_beta,np)
-      Vbeta <- check.Vbeta(V_beta,np)
+      V_beta <- check.Vbeta(V_beta,np)
       V_alpha <- check.Valpha(V_alpha)
       
       # call Rcpp function
       mod <- Rcpp_jSDM_binomial_logit_rand_site(ngibbs=ngibbs, nthin=nthin, nburn=nburn,
                                                 Y=Y,T=T, X=as.matrix(X),
-                                                beta_start=beta_start, mu_beta = mubeta, V_beta=Vbeta,
-                                                alpha_start=alpha_start, V_alpha_start=V_alpha, shape=shape, rate=rate,
+                                                beta_start=beta_start, mu_beta = mubeta, V_beta=V_beta,
+                                                alpha_start=alpha_start, V_alpha_start=V_alpha,
+                                                shape_Valpha=shape_Valpha, rate_Valpha=rate_Valpha,
                                                 ropt=ropt, seed=seed, verbose=verbose)
       
       
@@ -556,8 +557,9 @@ jSDM_binomial_logit <- function(# Iteration
                          presence_data=Y, trials=T, 
                          site_formula=site_formula,
                          site_data=site_data,  n_latent=n_latent,
-                         beta_start=beta_start, mu_beta=mubeta, V_beta=Vbeta,
-                         alpha_start=alpha_start, V_alpha_start=V_alpha, shape=shape, rate=rate,
+                         beta_start=beta_start, mu_beta=mubeta, V_beta=V_beta,
+                         alpha_start=alpha_start, V_alpha_start=V_alpha,
+                         shape_Valpha=shape_Valpha, rate_Valpha=rate_Valpha,
                          site_effect=site_effect, family="binomial", link="logit",
                          ropt=ropt, seed=seed, verbose=verbose)
       colnames(mod$logit_theta_latent) <- colnames(mod$theta_latent) <- colnames(Y)
@@ -584,13 +586,13 @@ jSDM_binomial_logit <- function(# Iteration
       
       # Form and check priors
       mubeta <- check.mubeta(mu_beta,np)
-      Vbeta <- check.Vbeta(V_beta,np)
+      V_beta <- check.Vbeta(V_beta,np)
       V_alpha <- check.Valpha(V_alpha)
       
       # call Rcpp function
       mod <- Rcpp_jSDM_binomial_logit_fixed_site(ngibbs=ngibbs, nthin=nthin, nburn=nburn,
                                                  Y=Y,T=T, X=as.matrix(X),
-                                                 beta_start=beta_start, mu_beta = mubeta, V_beta=Vbeta,
+                                                 beta_start=beta_start, mu_beta = mubeta, V_beta=V_beta,
                                                  alpha_start=alpha_start, V_alpha=V_alpha, 
                                                  ropt=ropt, seed=seed, verbose=verbose)
       
@@ -615,7 +617,7 @@ jSDM_binomial_logit <- function(# Iteration
                          presence_data=Y, trials=T, 
                          site_formula=site_formula,
                          site_data=site_data,  n_latent=n_latent,
-                         beta_start=beta_start, mu_beta=mubeta, V_beta=Vbeta,
+                         beta_start=beta_start, mu_beta=mubeta, V_beta=V_beta,
                          alpha_start=alpha_start, V_alpha=V_alpha, 
                          site_effect=site_effect, family="binomial", link="logit",
                          ropt=ropt, seed=seed, verbose=verbose)
@@ -646,7 +648,7 @@ jSDM_binomial_logit <- function(# Iteration
       
       # Form and check priors
       mubeta <- check.mubeta(mu_beta,np)
-      Vbeta <- check.Vbeta(V_beta,np)
+      V_beta <- check.Vbeta(V_beta,np)
       mulambda <- check.mubeta(mu_lambda,n_latent)
       Vlambda <- check.Vlambda(V_lambda,n_latent)
       V_W <- rep(1,n_latent)
@@ -655,7 +657,7 @@ jSDM_binomial_logit <- function(# Iteration
       # call Rcpp function
       mod <- Rcpp_jSDM_binomial_logit_fixed_site_lv(ngibbs=ngibbs, nthin=nthin, nburn=nburn,
                                                     Y=Y,T=T, X=as.matrix(X),
-                                                    beta_start=beta_start, mu_beta = mubeta, V_beta=Vbeta,
+                                                    beta_start=beta_start, mu_beta = mubeta, V_beta=V_beta,
                                                     lambda_start=lambda_start, mu_lambda = mulambda, V_lambda=Vlambda,
                                                     W_start = W_start, V_W = V_W,
                                                     alpha_start=alpha_start, V_alpha=V_alpha,
@@ -692,7 +694,7 @@ jSDM_binomial_logit <- function(# Iteration
                          presence_data=Y, trials=T, 
                          site_formula=site_formula,
                          site_data=site_data, n_latent=n_latent,
-                         beta_start=beta_start, mu_beta=mubeta, V_beta=Vbeta,
+                         beta_start=beta_start, mu_beta=mubeta, V_beta=V_beta,
                          lambda_start=lambda_start, mu_lambda=mulambda, V_lambda=Vlambda,
                          W_start=W_start, V_W=V_W,
                          alpha_start=alpha_start, V_alpha=V_alpha, site_effect=site_effect,
@@ -726,7 +728,7 @@ jSDM_binomial_logit <- function(# Iteration
       
       # Form and check priors
       mubeta <- check.mubeta(mu_beta,np)
-      Vbeta <- check.Vbeta(V_beta,np)
+      V_beta <- check.Vbeta(V_beta,np)
       mulambda <- check.mubeta(mu_lambda,n_latent)
       Vlambda <- check.Vlambda(V_lambda,n_latent)
       V_W <- rep(1,n_latent)
@@ -735,10 +737,11 @@ jSDM_binomial_logit <- function(# Iteration
       # call Rcpp function
       mod <- Rcpp_jSDM_binomial_logit_rand_site_lv(ngibbs=ngibbs, nthin=nthin, nburn=nburn,
                                                    Y=Y,T=T, X=as.matrix(X),
-                                                   beta_start=beta_start, mu_beta = mubeta, V_beta=Vbeta,
+                                                   beta_start=beta_start, mu_beta = mubeta, V_beta=V_beta,
                                                    lambda_start=lambda_start, mu_lambda = mulambda, V_lambda=Vlambda,
                                                    W_start = W_start, V_W = V_W,
-                                                   alpha_start=alpha_start, V_alpha_start=V_alpha, shape=shape, rate=rate,
+                                                   alpha_start=alpha_start, V_alpha_start=V_alpha,
+                                                   shape_Valpha=shape_Valpha, rate_Valpha=rate_Valpha,
                                                    ropt=ropt, seed=seed, verbose=verbose)
       
       
@@ -774,10 +777,11 @@ jSDM_binomial_logit <- function(# Iteration
                          presence_data=Y, trials=T, 
                          site_formula=site_formula,
                          site_data=site_data, n_latent=n_latent,
-                         beta_start=beta_start, mu_beta=mubeta, V_beta=Vbeta,
+                         beta_start=beta_start, mu_beta=mubeta, V_beta=V_beta,
                          lambda_start=lambda_start, mu_lambda=mulambda, V_lambda=Vlambda,
                          W_start=W_start, V_W=V_W,
-                         alpha_start=alpha_start, V_alpha_start=V_alpha, shape=shape, rate=rate,
+                         alpha_start=alpha_start, V_alpha_start=V_alpha,
+                         shape_Valpha=shape_Valpha, rate_Valpha=rate_Valpha,
                          site_effect=site_effect, family="binomial", link="logit",
                          ropt=ropt, seed=seed, verbose=verbose)
       colnames(mod$logit_theta_latent) <- colnames(mod$theta_latent) <- colnames(Y)
@@ -902,7 +906,7 @@ jSDM_binomial_logit <- function(# Iteration
                          trait_formula=trait_formula,
                          n_latent=n_latent, 
                          beta_start=beta_start, 
-                         V_beta=Vbeta,
+                         V_beta=V_beta,
                          gamma_start=gamma_start,
                          V_gamma=Vgamma, mu_gamma=mugamma,
                          gamma_zeros=gamma_zeros,
@@ -937,7 +941,7 @@ jSDM_binomial_logit <- function(# Iteration
       # Form and check priors
       mugamma <- check.mugamma.mat(mu_gamma,nt,np)
       Vgamma <- check.Vgamma.mat(V_gamma,nt,np)
-      Vbeta <- check.Vbeta(V_beta,np)
+      V_beta <- check.Vbeta(V_beta,np)
       mulambda <- check.mubeta(mu_lambda,n_latent)
       Vlambda <- check.Vlambda(V_lambda,n_latent)
       V_W <- rep(1,n_latent)
@@ -946,7 +950,7 @@ jSDM_binomial_logit <- function(# Iteration
       mod <- Rcpp_jSDM_binomial_logit_traits_lv(ngibbs=ngibbs, nthin=nthin, nburn=nburn,
                                                 Y=Y,T=T, X=as.matrix(X), Tr=as.matrix(Tr),
                                                 beta_start=beta_start,
-                                                V_beta=Vbeta,
+                                                V_beta=V_beta,
                                                 gamma_start=gamma_start,
                                                 V_gamma=Vgamma, mu_gamma=mugamma,
                                                 gamma_zeros=gamma_zeros,
@@ -993,7 +997,7 @@ jSDM_binomial_logit <- function(# Iteration
                          trait_formula=trait_formula,
                          n_latent=n_latent, 
                          beta_start=beta_start, 
-                         V_beta=Vbeta,
+                         V_beta=V_beta,
                          gamma_start=gamma_start,
                          V_gamma=Vgamma, mu_gamma=mugamma,
                          gamma_zeros=gamma_zeros,
@@ -1030,19 +1034,20 @@ jSDM_binomial_logit <- function(# Iteration
       # Form and check priors
       mugamma <- check.mugamma.mat(mu_gamma,nt,np)
       Vgamma <- check.Vgamma.mat(V_gamma,nt,np)
-      Vbeta <- check.Vbeta(V_beta,np)
+      V_beta <- check.Vbeta(V_beta,np)
       V_alpha <- check.Valpha(V_alpha)
       
       # call Rcpp function
       mod <- Rcpp_jSDM_binomial_logit_traits_rand_site(ngibbs=ngibbs, nthin=nthin, nburn=nburn,
                                                        Y=Y,T=T, X=as.matrix(X), Tr=as.matrix(Tr),
                                                        beta_start=beta_start,
-                                                       V_beta=Vbeta,
+                                                       V_beta=V_beta,
                                                        gamma_start=gamma_start,
                                                        V_gamma=Vgamma, mu_gamma=mugamma,
                                                        gamma_zeros=gamma_zeros,
                                                        alpha_start=alpha_start,
-                                                       V_alpha_start=V_alpha, shape=shape, rate=rate,
+                                                       V_alpha_start=V_alpha,
+                                                       shape_Valpha=shape_Valpha, rate_Valpha=rate_Valpha,
                                                        ropt=ropt, seed=seed, verbose=verbose)
       
       
@@ -1078,12 +1083,13 @@ jSDM_binomial_logit <- function(# Iteration
                          trait_formula=trait_formula,
                          n_latent=n_latent, 
                          beta_start=beta_start, 
-                         V_beta=Vbeta,
+                         V_beta=V_beta,
                          gamma_start=gamma_start,
                          V_gamma=Vgamma, mu_gamma=mugamma,
                          gamma_zeros=gamma_zeros,
                          alpha_start=alpha_start,
-                         V_alpha_start=V_alpha, shape=shape, rate=rate,
+                         V_alpha_start=V_alpha,
+                         shape_Valpha=shape_Valpha, rate_Valpha=rate_Valpha,
                          site_effect=site_effect, family="binomial", link="logit",
                          ropt=ropt, seed=seed, verbose=verbose)
       colnames(mod$logit_theta_latent) <- colnames(mod$theta_latent) <- colnames(Y)
@@ -1113,14 +1119,14 @@ jSDM_binomial_logit <- function(# Iteration
       # Form and check priors
       mugamma <- check.mugamma.mat(mu_gamma,nt,np)
       Vgamma <- check.Vgamma.mat(V_gamma,nt,np)
-      Vbeta <- check.Vbeta(V_beta,np)
+      V_beta <- check.Vbeta(V_beta,np)
       V_alpha <- check.Valpha(V_alpha)
       
       # call Rcpp function
       mod <- Rcpp_jSDM_binomial_logit_traits_fixed_site(ngibbs=ngibbs, nthin=nthin, nburn=nburn,
                                                         Y=Y,T=T, X=as.matrix(X), Tr=as.matrix(Tr),
                                                         beta_start=beta_start,
-                                                        V_beta=Vbeta,
+                                                        V_beta=V_beta,
                                                         gamma_start=gamma_start,
                                                         V_gamma=Vgamma, mu_gamma=mugamma,
                                                         gamma_zeros=gamma_zeros,
@@ -1158,7 +1164,7 @@ jSDM_binomial_logit <- function(# Iteration
                          trait_formula=trait_formula,
                          n_latent=n_latent, 
                          beta_start=beta_start, 
-                         V_beta=Vbeta,
+                         V_beta=V_beta,
                          gamma_start=gamma_start,
                          V_gamma=Vgamma, mu_gamma=mugamma,
                          gamma_zeros=gamma_zeros,
@@ -1195,7 +1201,7 @@ jSDM_binomial_logit <- function(# Iteration
       # Form and check priors
       mugamma <- check.mugamma.mat(mu_gamma,nt,np)
       Vgamma <- check.Vgamma.mat(V_gamma,nt,np)
-      Vbeta <- check.Vbeta(V_beta,np)
+      V_beta <- check.Vbeta(V_beta,np)
       mulambda <- check.mubeta(mu_lambda,n_latent)
       Vlambda <- check.Vlambda(V_lambda,n_latent)
       V_W <- rep(1,n_latent)
@@ -1205,7 +1211,7 @@ jSDM_binomial_logit <- function(# Iteration
       mod <- Rcpp_jSDM_binomial_logit_traits_fixed_site_lv(ngibbs=ngibbs, nthin=nthin, nburn=nburn,
                                                            Y=Y,T=T, X=as.matrix(X), Tr=as.matrix(Tr),
                                                            beta_start=beta_start,
-                                                           V_beta=Vbeta,
+                                                           V_beta=V_beta,
                                                            gamma_start=gamma_start,
                                                            V_gamma=Vgamma, mu_gamma=mugamma,
                                                            gamma_zeros=gamma_zeros,
@@ -1257,7 +1263,7 @@ jSDM_binomial_logit <- function(# Iteration
                          trait_formula=trait_formula,
                          n_latent=n_latent, 
                          beta_start=beta_start, 
-                         V_beta=Vbeta,
+                         V_beta=V_beta,
                          gamma_start=gamma_start,
                          V_gamma=Vgamma, mu_gamma=mugamma,
                          gamma_zeros=gamma_zeros,
@@ -1299,7 +1305,7 @@ jSDM_binomial_logit <- function(# Iteration
       # Form and check priors
       mugamma <- check.mugamma.mat(mu_gamma,nt,np)
       Vgamma <- check.Vgamma.mat(V_gamma,nt,np)
-      Vbeta <- check.Vbeta(V_beta,np)
+      V_beta <- check.Vbeta(V_beta,np)
       mulambda <- check.mubeta(mu_lambda,n_latent)
       Vlambda <- check.Vlambda(V_lambda,n_latent)
       V_W <- rep(1,n_latent)
@@ -1309,7 +1315,7 @@ jSDM_binomial_logit <- function(# Iteration
       mod <- Rcpp_jSDM_binomial_logit_traits_rand_site_lv(ngibbs=ngibbs, nthin=nthin, nburn=nburn,
                                                           Y=Y,T=T, X=as.matrix(X), Tr=as.matrix(Tr),
                                                           beta_start=beta_start,
-                                                          V_beta=Vbeta,
+                                                          V_beta=V_beta,
                                                           gamma_start=gamma_start,
                                                           V_gamma=Vgamma, mu_gamma=mugamma,
                                                           gamma_zeros=gamma_zeros,
@@ -1317,7 +1323,8 @@ jSDM_binomial_logit <- function(# Iteration
                                                           mu_lambda = mulambda, V_lambda=Vlambda,
                                                           W_start = W_start, V_W = V_W,
                                                           alpha_start=alpha_start,
-                                                          V_alpha_start=V_alpha, shape=shape, rate=rate,
+                                                          V_alpha_start=V_alpha,
+                                                          shape_Valpha=shape_Valpha, rate_Valpha=rate_Valpha,
                                                           ropt=ropt, seed=seed, verbose=verbose)
       
       
@@ -1364,7 +1371,7 @@ jSDM_binomial_logit <- function(# Iteration
                          trait_formula=trait_formula,
                          n_latent=n_latent, 
                          beta_start=beta_start, 
-                         V_beta=Vbeta,
+                         V_beta=V_beta,
                          gamma_start=gamma_start,
                          V_gamma=Vgamma, mu_gamma=mugamma,
                          gamma_zeros=gamma_zeros,
@@ -1372,7 +1379,8 @@ jSDM_binomial_logit <- function(# Iteration
                          mu_lambda=mulambda, V_lambda=Vlambda,
                          W_start=W_start, V_W=V_W,
                          alpha_start=alpha_start,
-                         V_alpha_start=V_alpha, shape=shape, rate=rate,
+                         V_alpha_start=V_alpha,
+                         shape_Valpha=shape_Valpha, rate_Valpha=rate_Valpha,
                          site_effect=site_effect, family="binomial", link="logit",
                          ropt=ropt, seed=seed, verbose=verbose)
       colnames(mod$logit_theta_latent) <- colnames(mod$theta_latent) <- colnames(Y)
