@@ -43,9 +43,9 @@
 #'  If \code{alpha_start} takes a scalar value, then that value will serve for all of the \eqn{\alpha} parameters.
 #' @param V_alpha Starting value for variance of random site effect if \code{site_effect="random"} or constant variance of the Gaussian prior distribution for the fixed site effect if 
 #' \code{site_effect="fixed"}. Must be a strictly positive scalar, ignored if \code{site_effect="none"}.
-#' @param shape Shape parameter of the Inverse-Gamma prior for the random site effect variance \code{V_alpha}, ignored if \code{site_effect="none"} or \code{site_effect="fixed"}. 
+#' @param shape_Valpha Shape parameter of the Inverse-Gamma prior for the random site effect variance \code{V_alpha}, ignored if \code{site_effect="none"} or \code{site_effect="fixed"}. 
 #' Must be a strictly positive scalar. Default to 0.5 for weak informative prior.
-#' @param rate Rate parameter of the Inverse-Gamma prior for the random site effect variance \code{V_alpha}, ignored if \code{site_effect="none"} or \code{site_effect="fixed"}
+#' @param rate_Valpha Rate parameter of the Inverse-Gamma prior for the random site effect variance \code{V_alpha}, ignored if \code{site_effect="none"} or \code{site_effect="fixed"}
 #' Must be a strictly positive scalar. Default to 0.0005 for weak informative prior.
 #' @param mu_beta Means of the Normal priors for the \eqn{\beta}{\beta} parameters of the suitability process. \code{mu_beta} must be either a scalar or a \eqn{np}-length vector.
 #'  If \code{mu_beta} takes a scalar value, then that value will serve as the prior mean for all of the \eqn{\beta} parameters.
@@ -229,7 +229,8 @@
 #'                            W_start=0,
 #'                            V_alpha=1,
 #'                            # Priors
-#'                            shape=0.5, rate=0.0005,
+#'                            shape_Valpha=0.5,
+#'                            rate_Valpha=0.0005,
 #'                            mu_beta=0, V_beta=1,
 #'                            mu_lambda=0, V_lambda=1,
 #'                            seed=1234, verbose=1)
@@ -355,7 +356,8 @@ jSDM_binomial_probit <- function(#Iteration
                                  mu_beta=0, V_beta=10,
                                  mu_lambda=0, V_lambda=10,
                                  mu_gamma=0, V_gamma=10, 
-                                 shape=0.5, rate=0.0005,
+                                 shape_Valpha=0.5,
+                                 rate_Valpha=0.0005,
                                  seed=1234, verbose=1)
 {   
   #===== Basic checks =====
@@ -606,7 +608,7 @@ jSDM_binomial_probit <- function(#Iteration
                                                  beta_start=beta_start, 
                                                  V_beta=Vbeta, mu_beta=mubeta,
                                                  alpha_start=alpha_start, V_alpha_start=V_alpha,
-                                                 shape = shape, rate = rate,
+                                                 shape_Valpha = shape_Valpha, rate_Valpha = rate_Valpha,
                                                  seed=seed, verbose=verbose)
       
       #= Transform Sample list in an MCMC object
@@ -630,7 +632,8 @@ jSDM_binomial_probit <- function(#Iteration
                          site_data=site_data, n_latent=n_latent,
                          burnin=burnin, mcmc=mcmc, thin=thin,
                          beta_start=beta_start, alpha_start=alpha_start,
-                         V_alpha_start=V_alpha, shape=shape, rate=rate,
+                         V_alpha_start=V_alpha,
+                         shape_Valpha=shape_Valpha, rate_Valpha=rate_Valpha,
                          site_effect=site_effect, 
                          mu_beta=mubeta, V_beta=Vbeta,
                          family="binomial", link="probit",
@@ -749,7 +752,7 @@ jSDM_binomial_probit <- function(#Iteration
                                                     lambda_start= lambda_start, V_lambda=Vlambda, mu_lambda = mulambda,
                                                     W_start=W_start, V_W=V_W,
                                                     alpha_start=alpha_start, V_alpha_start=V_alpha,
-                                                    shape = shape, rate = rate,
+                                                    shape_Valpha = shape_Valpha, rate_Valpha = rate_Valpha,
                                                     seed=seed, verbose=verbose)
       
       #= Transform Sample list in an MCMC object
@@ -784,7 +787,8 @@ jSDM_binomial_probit <- function(#Iteration
                          beta_start=beta_start,
                          V_beta=Vbeta, mu_beta=mubeta,
                          lambda_start=lambda_start, mu_lambda=mulambda, V_lambda=Vlambda,
-                         alpha_start=alpha_start, V_alpha_start=V_alpha, shape=shape, rate=rate,
+                         alpha_start=alpha_start, V_alpha_start=V_alpha,
+                         shape_Valpha=shape_Valpha, rate_Valpha=rate_Valpha,
                          site_effect=site_effect, W_start=W_start, V_W=V_W,
                          family="binomial", link="probit",
                          seed=seed, verbose=verbose)
@@ -1116,7 +1120,7 @@ jSDM_binomial_probit <- function(#Iteration
                                                         beta_start=beta_start, 
                                                         V_beta=Vbeta,
                                                         alpha_start=alpha_start, V_alpha_start=V_alpha,
-                                                        shape = shape, rate = rate,
+                                                        shape_Valpha = shape_Valpha, rate_Valpha = rate_Valpha,
                                                         gamma_start=gamma_start,
                                                         V_gamma=Vgamma, mu_gamma=mugamma,
                                                         gamma_zeros=gamma_zeros,
@@ -1153,7 +1157,8 @@ jSDM_binomial_probit <- function(#Iteration
                          n_latent=n_latent,
                          burnin=burnin, mcmc=mcmc, thin=thin,
                          beta_start=beta_start, alpha_start=alpha_start,
-                         V_alpha_start=V_alpha, shape=shape, rate=rate,
+                         V_alpha_start=V_alpha,
+                         shape_Valpha=shape_Valpha, rate_Valpha=rate_Valpha,
                          gamma_start=gamma_start,
                          V_gamma=Vgamma, mu_gamma=mugamma,
                          gamma_zeros=gamma_zeros,
@@ -1299,7 +1304,7 @@ jSDM_binomial_probit <- function(#Iteration
                                                            lambda_start= lambda_start, V_lambda=Vlambda, mu_lambda = mulambda,
                                                            W_start=W_start, V_W=V_W,
                                                            alpha_start=alpha_start, V_alpha_start=V_alpha,
-                                                           shape = shape, rate = rate,
+                                                           shape_Valpha = shape_Valpha, rate_Valpha = rate_Valpha,
                                                            gamma_start=gamma_start,
                                                            V_gamma=Vgamma, mu_gamma=mugamma,
                                                            gamma_zeros=gamma_zeros,
@@ -1352,7 +1357,8 @@ jSDM_binomial_probit <- function(#Iteration
                          lambda_start=lambda_start,
                          mu_lambda=mulambda, V_lambda=Vlambda,
                          alpha_start=alpha_start,
-                         V_alpha_start=V_alpha, shape=shape, rate=rate,
+                         V_alpha_start=V_alpha,
+                         shape_Valpha=shape_Valpha, rate_Valpha=rate_Valpha,
                          site_effect=site_effect,
                          W_start=W_start, V_W=V_W,
                          family="binomial", link="probit",
