@@ -46,9 +46,9 @@
 #'  If \code{alpha_start} takes a scalar value, then that value will serve for all of the \eqn{\alpha} parameters.
 #' @param V_alpha Starting value for variance of random site effect if \code{site_effect="random"} or constant variance of the Gaussian prior distribution for the fixed site effect if 
 #' \code{site_effect="fixed"}. Must be a strictly positive scalar, ignored if \code{site_effect="none"}.
-#' @param shape Shape parameter of the Inverse-Gamma prior for the random site effect variance \code{V_alpha}, ignored if \code{site_effect="none"} or \code{site_effect="fixed"}. 
+#' @param shape_Valpha Shape parameter of the Inverse-Gamma prior for the random site effect variance \code{V_alpha}, ignored if \code{site_effect="none"} or \code{site_effect="fixed"}. 
 #' Must be a strictly positive scalar. Default to 0.5 for weak informative prior.
-#' @param rate Rate parameter of the Inverse-Gamma prior for the random site effect variance \code{V_alpha}, ignored if \code{site_effect="none"} or \code{site_effect="fixed"}
+#' @param rate_Valpha Rate parameter of the Inverse-Gamma prior for the random site effect variance \code{V_alpha}, ignored if \code{site_effect="none"} or \code{site_effect="fixed"}
 #' Must be a strictly positive scalar. Default to 0.0005 for weak informative prior.
 #' @param mu_beta Means of the Normal priors for the \eqn{\beta}{\beta} parameters of the suitability process. \code{mu_beta} must be either a scalar or a \eqn{np}-length vector.
 #'  If \code{mu_beta} takes a scalar value, then that value will serve as the prior mean for all of the \eqn{\beta} parameters.
@@ -135,7 +135,8 @@
 #'   \tab \emph{trait effect} \tab \tab interaction \tab traits \tab environment \tab \tab \cr 
 #' }
 #'  
-#' @examples #==============================================
+#' @examples 
+#' #==============================================
 #' # jSDM_poisson_log()
 #' # Example with simulated data
 #' #==============================================
@@ -197,8 +198,8 @@
 #'                         alpha_start=0,
 #'                         V_alpha=1,
 #'                         # Priors
-#'                         shape=0.5,
-#'                         rate=0.0005,
+#'                         shape_Valpha=0.5,
+#'                         rate_Valpha=0.0005,
 #'                         mu_beta=0,
 #'                         V_beta=10,
 #'                         mu_lambda=0,
@@ -329,7 +330,8 @@ jSDM_poisson_log  <- function(# Iteration
                               alpha_start=0, 
                               V_alpha=1,
                               # Priors 
-                              shape=0.5, rate=0.0005,
+                              shape_Valpha=0.5,
+                              rate_Valpha=0.0005,
                               mu_beta=0, V_beta=10,
                               mu_gamma=0, V_gamma=10, 
                               mu_lambda=0, V_lambda=10,
@@ -440,7 +442,7 @@ jSDM_poisson_log  <- function(# Iteration
       
       # Form and check priors
       mubeta <- check.mubeta(mu_beta,np)
-      Vbeta <- check.Vbeta(V_beta,np)
+      V_beta <- check.Vbeta(V_beta,np)
       mulambda <- check.mubeta(mu_lambda,n_latent)
       Vlambda <- check.Vlambda(V_lambda,n_latent)
       V_W <- rep(1,n_latent)
@@ -448,7 +450,7 @@ jSDM_poisson_log  <- function(# Iteration
       # call Rcpp function
       mod <- Rcpp_jSDM_poisson_log_lv(ngibbs=ngibbs, nthin=nthin, nburn=nburn,
                                       Y=Y, X=as.matrix(X),
-                                      beta_start=beta_start, mu_beta = mubeta, V_beta=Vbeta,
+                                      beta_start=beta_start, mu_beta = mubeta, V_beta=V_beta,
                                       lambda_start=lambda_start, mu_lambda = mulambda, V_lambda=Vlambda,
                                       W_start = W_start, V_W = V_W,
                                       ropt=ropt, seed=seed, verbose=verbose)
@@ -481,7 +483,7 @@ jSDM_poisson_log  <- function(# Iteration
                          count_data=Y,
                          site_formula=site_formula,
                          site_data=site_data, n_latent=n_latent,
-                         beta_start=beta_start, mu_beta=mubeta, V_beta=Vbeta,
+                         beta_start=beta_start, mu_beta=mubeta, V_beta=V_beta,
                          lambda_start=lambda_start, mu_lambda=mulambda, V_lambda=Vlambda,
                          W_start=W_start, V_W=V_W,
                          site_effect=site_effect, family="poisson", link="log",
@@ -511,14 +513,15 @@ jSDM_poisson_log  <- function(# Iteration
       
       # Form and check priors
       mubeta <- check.mubeta(mu_beta,np)
-      Vbeta <- check.Vbeta(V_beta,np)
+      V_beta <- check.Vbeta(V_beta,np)
       V_alpha <- check.Valpha(V_alpha)
       
       # call Rcpp function
       mod <- Rcpp_jSDM_poisson_log_rand_site(ngibbs=ngibbs, nthin=nthin, nburn=nburn,
                                              Y=Y, X=as.matrix(X),
-                                             beta_start=beta_start, mu_beta = mubeta, V_beta=Vbeta,
-                                             alpha_start=alpha_start, V_alpha_start=V_alpha, shape=shape, rate=rate,
+                                             beta_start=beta_start, mu_beta = mubeta, V_beta=V_beta,
+                                             alpha_start=alpha_start, V_alpha_start=V_alpha,
+                                             shape_Valpha=shape_Valpha, rate_Valpha=rate_Valpha,
                                              ropt=ropt, seed=seed, verbose=verbose)
       
       
@@ -544,8 +547,9 @@ jSDM_poisson_log  <- function(# Iteration
                          count_data=Y,
                          site_formula=site_formula,
                          site_data=site_data,  n_latent=n_latent,
-                         beta_start=beta_start, mu_beta=mubeta, V_beta=Vbeta,
-                         alpha_start=alpha_start, V_alpha_start=V_alpha, shape=shape, rate=rate,
+                         beta_start=beta_start, mu_beta=mubeta, V_beta=V_beta,
+                         alpha_start=alpha_start, V_alpha_start=V_alpha,
+                         shape_Valpha=shape_Valpha, rate_Valpha=rate_Valpha,
                          site_effect=site_effect, family="poisson", link="log",
                          ropt=ropt, seed=seed, verbose=verbose)
       colnames(mod$log_theta_latent) <- colnames(mod$theta_latent) <- colnames(Y)
@@ -573,13 +577,13 @@ jSDM_poisson_log  <- function(# Iteration
       
       # Form and check priors
       mubeta <- check.mubeta(mu_beta,np)
-      Vbeta <- check.Vbeta(V_beta,np)
+      V_beta <- check.Vbeta(V_beta,np)
       V_alpha <- check.Valpha(V_alpha)
       
       # call Rcpp function
       mod <- Rcpp_jSDM_poisson_log_fixed_site(ngibbs=ngibbs, nthin=nthin, nburn=nburn,
                                               Y=Y, X=as.matrix(X),
-                                              beta_start=beta_start, mu_beta = mubeta, V_beta=Vbeta,
+                                              beta_start=beta_start, mu_beta = mubeta, V_beta=V_beta,
                                               alpha_start=alpha_start, V_alpha=V_alpha, 
                                               ropt=ropt, seed=seed, verbose=verbose)
       
@@ -604,7 +608,7 @@ jSDM_poisson_log  <- function(# Iteration
                          count_data=Y,
                          site_formula=site_formula,
                          site_data=site_data,  n_latent=n_latent,
-                         beta_start=beta_start, mu_beta=mubeta, V_beta=Vbeta,
+                         beta_start=beta_start, mu_beta=mubeta, V_beta=V_beta,
                          alpha_start=alpha_start, V_alpha=V_alpha, 
                          site_effect=site_effect, family="poisson", link="log",
                          ropt=ropt, seed=seed, verbose=verbose)
@@ -635,7 +639,7 @@ jSDM_poisson_log  <- function(# Iteration
       
       # Form and check priors
       mubeta <- check.mubeta(mu_beta,np)
-      Vbeta <- check.Vbeta(V_beta,np)
+      V_beta <- check.Vbeta(V_beta,np)
       mulambda <- check.mubeta(mu_lambda,n_latent)
       Vlambda <- check.Vlambda(V_lambda,n_latent)
       V_W <- rep(1,n_latent)
@@ -644,7 +648,7 @@ jSDM_poisson_log  <- function(# Iteration
       # call Rcpp function
       mod <- Rcpp_jSDM_poisson_log_fixed_site_lv(ngibbs=ngibbs, nthin=nthin, nburn=nburn,
                                                  Y=Y, X=as.matrix(X),
-                                                 beta_start=beta_start, mu_beta = mubeta, V_beta=Vbeta,
+                                                 beta_start=beta_start, mu_beta = mubeta, V_beta=V_beta,
                                                  lambda_start=lambda_start, mu_lambda = mulambda, V_lambda=Vlambda,
                                                  W_start = W_start, V_W = V_W,
                                                  alpha_start=alpha_start, V_alpha=V_alpha,
@@ -681,7 +685,7 @@ jSDM_poisson_log  <- function(# Iteration
                          count_data=Y,
                          site_formula=site_formula,
                          site_data=site_data, n_latent=n_latent,
-                         beta_start=beta_start, mu_beta=mubeta, V_beta=Vbeta,
+                         beta_start=beta_start, mu_beta=mubeta, V_beta=V_beta,
                          lambda_start=lambda_start, mu_lambda=mulambda, V_lambda=Vlambda,
                          W_start=W_start, V_W=V_W,
                          alpha_start=alpha_start, V_alpha=V_alpha, site_effect=site_effect,
@@ -714,7 +718,7 @@ jSDM_poisson_log  <- function(# Iteration
       
       # Form and check priors
       mubeta <- check.mubeta(mu_beta,np)
-      Vbeta <- check.Vbeta(V_beta,np)
+      V_beta <- check.Vbeta(V_beta,np)
       mulambda <- check.mubeta(mu_lambda,n_latent)
       Vlambda <- check.Vlambda(V_lambda,n_latent)
       V_W <- rep(1,n_latent)
@@ -723,10 +727,14 @@ jSDM_poisson_log  <- function(# Iteration
       # call Rcpp function
       mod <- Rcpp_jSDM_poisson_log_rand_site_lv(ngibbs=ngibbs, nthin=nthin, nburn=nburn,
                                                 Y=Y, X=as.matrix(X),
-                                                beta_start=beta_start, mu_beta = mubeta, V_beta=Vbeta,
-                                                lambda_start=lambda_start, mu_lambda = mulambda, V_lambda=Vlambda,
+                                                beta_start=beta_start,
+                                                mu_beta = mubeta, V_beta=V_beta,
+                                                lambda_start=lambda_start,
+                                                mu_lambda = mulambda, V_lambda=Vlambda,
                                                 W_start = W_start, V_W = V_W,
-                                                alpha_start=alpha_start, V_alpha_start=V_alpha, shape=shape, rate=rate,
+                                                alpha_start=alpha_start,
+                                                V_alpha_start=V_alpha,
+                                                shape_Valpha=shape_Valpha, rate_Valpha=rate_Valpha,
                                                 ropt=ropt, seed=seed, verbose=verbose)
       
       
@@ -762,10 +770,14 @@ jSDM_poisson_log  <- function(# Iteration
                          count_data=Y, 
                          site_formula=site_formula,
                          site_data=site_data, n_latent=n_latent,
-                         beta_start=beta_start, mu_beta=mubeta, V_beta=Vbeta,
-                         lambda_start=lambda_start, mu_lambda=mulambda, V_lambda=Vlambda,
+                         beta_start=beta_start,
+                         mu_beta=mubeta, V_beta=V_beta,
+                         lambda_start=lambda_start,
+                         mu_lambda=mulambda, V_lambda=Vlambda,
                          W_start=W_start, V_W=V_W,
-                         alpha_start=alpha_start, V_alpha_start=V_alpha, shape=shape, rate=rate,
+                         alpha_start=alpha_start,
+                         V_alpha_start=V_alpha,
+                         shape_Valpha=shape_Valpha, rate_Valpha=rate_Valpha,
                          site_effect=site_effect, family="poisson", link="log",
                          ropt=ropt, seed=seed, verbose=verbose)
       colnames(mod$log_theta_latent) <- colnames(mod$theta_latent) <- colnames(Y)
@@ -891,7 +903,7 @@ jSDM_poisson_log  <- function(# Iteration
                          trait_formula=trait_formula,
                          n_latent=n_latent, 
                          beta_start=beta_start, 
-                         V_beta=Vbeta,
+                         V_beta=V_beta,
                          gamma_start=gamma_start,
                          V_gamma=Vgamma, mu_gamma=mugamma,
                          gamma_zeros=gamma_zeros,
@@ -926,7 +938,7 @@ jSDM_poisson_log  <- function(# Iteration
       # Form and check priors
       mugamma <- check.mugamma.mat(mu_gamma,nt,np)
       Vgamma <- check.Vgamma.mat(V_gamma,nt,np)
-      Vbeta <- check.Vbeta(V_beta,np)
+      V_beta <- check.Vbeta(V_beta,np)
       mulambda <- check.mubeta(mu_lambda,n_latent)
       Vlambda <- check.Vlambda(V_lambda,n_latent)
       V_W <- rep(1,n_latent)
@@ -938,7 +950,7 @@ jSDM_poisson_log  <- function(# Iteration
                                              gamma_start=gamma_start,
                                              V_gamma=Vgamma, mu_gamma=mugamma,
                                              gamma_zeros=gamma_zeros, 
-                                             V_beta=Vbeta,
+                                             V_beta=V_beta,
                                              lambda_start=lambda_start,
                                              mu_lambda = mulambda, V_lambda=Vlambda,
                                              W_start = W_start, V_W = V_W,
@@ -982,7 +994,7 @@ jSDM_poisson_log  <- function(# Iteration
                          trait_formula=trait_formula,
                          n_latent=n_latent, 
                          beta_start=beta_start, 
-                         V_beta=Vbeta,
+                         V_beta=V_beta,
                          gamma_start=gamma_start,
                          V_gamma=Vgamma, mu_gamma=mugamma,
                          gamma_zeros=gamma_zeros,
@@ -1019,19 +1031,20 @@ jSDM_poisson_log  <- function(# Iteration
       # Form and check priors
       mugamma <- check.mugamma.mat(mu_gamma,nt,np)
       Vgamma <- check.Vgamma.mat(V_gamma,nt,np)
-      Vbeta <- check.Vbeta(V_beta,np)
+      V_beta <- check.Vbeta(V_beta,np)
       V_alpha <- check.Valpha(V_alpha)
       
       # call Rcpp function
       mod <- Rcpp_jSDM_poisson_log_traits_rand_site(ngibbs=ngibbs, nthin=nthin, nburn=nburn,
                                                     Y=Y, X=as.matrix(X), Tr=as.matrix(Tr),
                                                     beta_start=beta_start,
-                                                    V_beta=Vbeta,
+                                                    V_beta=V_beta,
                                                     gamma_start=gamma_start,
                                                     V_gamma=Vgamma, mu_gamma=mugamma,
                                                     gamma_zeros=gamma_zeros,
                                                     alpha_start=alpha_start,
-                                                    V_alpha_start=V_alpha, shape=shape, rate=rate,
+                                                    V_alpha_start=V_alpha,
+                                                    shape_Valpha=shape_Valpha, rate_Valpha=rate_Valpha,
                                                     ropt=ropt, seed=seed, verbose=verbose)
       
       
@@ -1067,12 +1080,13 @@ jSDM_poisson_log  <- function(# Iteration
                          trait_formula=trait_formula,
                          n_latent=n_latent, 
                          beta_start=beta_start, 
-                         V_beta=Vbeta,
+                         V_beta=V_beta,
                          gamma_start=gamma_start,
                          V_gamma=Vgamma, mu_gamma=mugamma,
                          gamma_zeros=gamma_zeros,
                          alpha_start=alpha_start,
-                         V_alpha_start=V_alpha, shape=shape, rate=rate,
+                         V_alpha_start=V_alpha,
+                         shape_Valpha=shape_Valpha, rate_Valpha=rate_Valpha,
                          site_effect=site_effect, family="poisson", link="log",
                          ropt=ropt, seed=seed, verbose=verbose)
       colnames(mod$log_theta_latent) <- colnames(mod$theta_latent) <- colnames(Y)
@@ -1103,7 +1117,7 @@ jSDM_poisson_log  <- function(# Iteration
       # Form and check priors
       mugamma <- check.mugamma.mat(mu_gamma,nt,np)
       Vgamma <- check.Vgamma.mat(V_gamma,nt,np)
-      Vbeta <- check.Vbeta(V_beta,np)
+      V_beta <- check.Vbeta(V_beta,np)
       V_alpha <- check.Valpha(V_alpha)
       
       # call Rcpp function
@@ -1113,7 +1127,7 @@ jSDM_poisson_log  <- function(# Iteration
                                                      gamma_start=gamma_start,
                                                      V_gamma=Vgamma, mu_gamma=mugamma,
                                                      gamma_zeros=gamma_zeros,
-                                                     V_beta=Vbeta,
+                                                     V_beta=V_beta,
                                                      alpha_start=alpha_start, V_alpha=V_alpha, 
                                                      ropt=ropt, seed=seed, verbose=verbose)
       
@@ -1148,7 +1162,7 @@ jSDM_poisson_log  <- function(# Iteration
                          trait_formula=trait_formula,
                          n_latent=n_latent, 
                          beta_start=beta_start, 
-                         V_beta=Vbeta,
+                         V_beta=V_beta,
                          gamma_start=gamma_start,
                          V_gamma=Vgamma, mu_gamma=mugamma,
                          gamma_zeros=gamma_zeros,
@@ -1185,7 +1199,7 @@ jSDM_poisson_log  <- function(# Iteration
       # Form and check priors
       mugamma <- check.mugamma.mat(mu_gamma,nt,np)
       Vgamma <- check.Vgamma.mat(V_gamma,nt,np)
-      Vbeta <- check.Vbeta(V_beta,np)
+      V_beta <- check.Vbeta(V_beta,np)
       mulambda <- check.mubeta(mu_lambda,n_latent)
       Vlambda <- check.Vlambda(V_lambda,n_latent)
       V_W <- rep(1,n_latent)
@@ -1198,7 +1212,7 @@ jSDM_poisson_log  <- function(# Iteration
                                                         gamma_start=gamma_start,
                                                         V_gamma=Vgamma, mu_gamma=mugamma,
                                                         gamma_zeros=gamma_zeros,
-                                                        V_beta=Vbeta,
+                                                        V_beta=V_beta,
                                                         lambda_start=lambda_start,
                                                         mu_lambda = mulambda, V_lambda=Vlambda,
                                                         W_start = W_start, V_W = V_W,
@@ -1247,7 +1261,7 @@ jSDM_poisson_log  <- function(# Iteration
                          trait_formula=trait_formula,
                          n_latent=n_latent, 
                          beta_start=beta_start, 
-                         V_beta=Vbeta,
+                         V_beta=V_beta,
                          gamma_start=gamma_start,
                          V_gamma=Vgamma, mu_gamma=mugamma,
                          gamma_zeros=gamma_zeros,
@@ -1288,7 +1302,7 @@ jSDM_poisson_log  <- function(# Iteration
       # Form and check priors
       mugamma <- check.mugamma.mat(mu_gamma,nt,np)
       Vgamma <- check.Vgamma.mat(V_gamma,nt,np)
-      Vbeta <- check.Vbeta(V_beta,np)
+      V_beta <- check.Vbeta(V_beta,np)
       mulambda <- check.mubeta(mu_lambda,n_latent)
       Vlambda <- check.Vlambda(V_lambda,n_latent)
       V_W <- rep(1,n_latent)
@@ -1301,13 +1315,14 @@ jSDM_poisson_log  <- function(# Iteration
                                                        gamma_start=gamma_start,
                                                        V_gamma=Vgamma, mu_gamma=mugamma,
                                                        gamma_zeros=gamma_zeros,
-                                                       V_beta=Vbeta,
+                                                       V_beta=V_beta,
                                                        lambda_start=lambda_start,
                                                        mu_lambda = mulambda, V_lambda=Vlambda,
                                                        W_start = W_start, V_W = V_W,
                                                        alpha_start=alpha_start,
                                                        V_alpha_start=V_alpha,
-                                                       shape=shape, rate=rate,
+                                                       shape_Valpha=shape_Valpha,
+                                                       rate_Valpha=rate_Valpha,
                                                        ropt=ropt, seed=seed, verbose=verbose)
       
       
@@ -1354,7 +1369,7 @@ jSDM_poisson_log  <- function(# Iteration
                          trait_formula=trait_formula,
                          n_latent=n_latent, 
                          beta_start=beta_start, 
-                         V_beta=Vbeta,
+                         V_beta=V_beta,
                          gamma_start=gamma_start,
                          V_gamma=Vgamma, mu_gamma=mugamma,
                          gamma_zeros=gamma_zeros,
@@ -1362,7 +1377,8 @@ jSDM_poisson_log  <- function(# Iteration
                          mu_lambda=mulambda, V_lambda=Vlambda,
                          W_start=W_start, V_W=V_W,
                          alpha_start=alpha_start,
-                         V_alpha_start=V_alpha, shape=shape, rate=rate,
+                         V_alpha_start=V_alpha,
+                         shape_Valpha=shape_Valpha, rate_Valpha=rate_Valpha,
                          site_effect=site_effect, family="poisson", link="log",
                          ropt=ropt, seed=seed, verbose=verbose)
       colnames(mod$log_theta_latent) <- colnames(mod$theta_latent) <- colnames(Y)
