@@ -157,6 +157,7 @@ add_species_arrows = function(radius = 5.0, label = "Species", reverse = TRUE, s
 #' @param R  matrix of correlation \eqn{R}
 #' @param radius circle's radius
 #' @param main title
+#' @param cex.main title's character size. NULL and NA are equivalent to 1.0.
 #' @param circleBreak circle break or not
 #' @param top number of top negative and positive associations to consider
 #' @param occ species occurence data
@@ -172,9 +173,10 @@ add_species_arrows = function(radius = 5.0, label = "Species", reverse = TRUE, s
 #' @param species_indices indices for sorting species
 #' @details  After fitting the jSDM with latent variables, the \bold{fullspecies residual correlation matrix} : \eqn{R=(R_{ij})}{R=(R_ij)} with \eqn{i=1,\ldots, n_{species}}{i=1,..., n_species} and \eqn{j=1,\ldots, n_{species}}{j=1,..., n_species} can be derived from the covariance in the latent variables such as : 
 #'  can be derived from the covariance in the latent variables such as : 
+#'  \eqn{\Sigma_{ij}=\lambda_i' .\lambda_j}{Sigma_ij=\lambda_i' . \lambda_j}, in the case of a regression with probit, logit or poisson link function and 
 #' \tabular{lll}{
-#' \eqn{\Sigma_{ij}}{Sigma_ij} \tab \eqn{= \lambda_i .\lambda_j' + 1}{= \lambda_i . \lambda_j' + 1} \tab if i=j \cr
-#'          \tab \eqn{= \lambda_i .\lambda_j'}{= \lambda_i . \lambda_j'} \tab else, \cr}
+#' \eqn{\Sigma_{ij}}{Sigma_ij} \tab \eqn{= \lambda_i' .\lambda_j + V}{= \lambda_i' . \lambda_j + V} \tab if i=j \cr
+#'          \tab \eqn{= \lambda_i' .\lambda_j}{= \lambda_i' . \lambda_j} \tab else, \cr}
 #' this function represents the correlations computed from covariances :
 #'\deqn{R_{ij} = \frac{\Sigma_{ij}}{\sqrt{\Sigma_ii\Sigma _jj}}}{R_ij = Sigma_ij / sqrt(Sigma_ii.Sigma _jj)}.
 #' @author 
@@ -183,7 +185,7 @@ add_species_arrows = function(radius = 5.0, label = "Species", reverse = TRUE, s
 #' 
 #' Jeanne Clément <jeanne.clement16@laposte.net>
 #' @references Pichler M. and Hartig F. (2021) A new method for faster and more accurate inference of species associations from big community data. \cr
-#'             \emph{Methods in Ecology and Evolution}, 12, 2159-2173 (doi:10.1111/2041-210X.13687).
+#'             \emph{Methods in Ecology and Evolution}, 12, 2159-2173 \doi{10.1111/2041-210X.13687}.
 #' @seealso \code{\link{jSDM-package}} \code{\link{get_residual_cor}} \cr
 #' \code{\link{jSDM_binomial_probit}} \code{\link{jSDM_binomial_probit_long_format}} \cr
 #' \code{\link{jSDM_binomial_probit_sp_constrained}} \code{\link{jSDM_binomial_logit}}  \code{\link{jSDM_poisson_log}} 
@@ -232,7 +234,7 @@ add_species_arrows = function(radius = 5.0, label = "Species", reverse = TRUE, s
 #' plot_associations(R, env_effect = env_effect, species_order="main env_effect")
 #' @importFrom graphics polygon text 
 #' @export
-plot_associations = function(R, radius = 5.0, main = NULL, 
+plot_associations = function(R, radius = 5.0, main = NULL, cex.main=NULL, 
                              circleBreak = FALSE, top = 10L, occ = NULL, env_effect=NULL, 
                              cols_association = c("#FF0000", "#BF003F", "#7F007F",
                                                   "#3F00BF", "#0000FF"),
@@ -252,7 +254,7 @@ plot_associations = function(R, radius = 5.0, main = NULL,
     lineSeq = 0.94*radius
     nseg = 100
     graphics::plot(NULL, NULL, xlim = c(-radius,radius), ylim =c(-radius,radius),pty="s", axes = F, xlab = "", ylab = "")
-    if(!is.null(main)) graphics::text(x = 0, y = radius*1.35, pos = 3, xpd = NA, labels = main)
+    if(!is.null(main)) graphics::text(x = 0, y = radius*1.25, pos = 3, xpd = NA, labels = main, cex=cex.main)
     xx = lineSeq*cos( seq(0,2*pi, length.out=nseg))
     yy = lineSeq*sin( seq(0,2*pi, length.out=nseg))
     
@@ -347,7 +349,7 @@ plot_associations = function(R, radius = 5.0, main = NULL,
     lineSeq = 0.94*radius
     nseg = 100
     graphics::plot(NULL, NULL, xlim = c(-radius,radius), ylim =c(-radius,radius),pty="s", axes = F, xlab = "", ylab = "")
-    if(!is.null(main)) graphics::text(x = 0, y = radius*1.35, pos = 3, xpd = NA, labels = main)
+    if(!is.null(main)) graphics::text(x = 0, y = radius*1.35, pos = 3, xpd = NA, labels = main, cex=cex.main)
     xx = lineSeq*cos( seq(0,2*pi, length.out=nseg))
     yy = lineSeq*sin( seq(0,2*pi, length.out=nseg))
     polygon(xx,yy, col= "white", border = "black", lty = 1, lwd = 1)
@@ -386,7 +388,8 @@ plot_associations = function(R, radius = 5.0, main = NULL,
       angleName = (from+to)/2
       if(angleName > 180) reverse = TRUE
       else reverse = FALSE
-      curve_text(angleName, label = colnames(env_effect)[i],reverse = reverse, radius=radius+d, middle = TRUE, extend = 1.17, col = cols[i])
+      curve_text(angleName, label = colnames(env_effect)[i],reverse = reverse, radius=radius+d,
+                 middle = TRUE, extend = 1.17, col = cols[i])
       #y
       polygon(x, y, xpd = NA,col = cols[i])
       text(srt = 0, 
