@@ -88,8 +88,8 @@ Rcpp::List  Rcpp_jSDM_binomial_logit_traits_fixed_site(
   dens_data.site_alpha = 0;
   dens_data.V_alpha_run = V_alpha;
   dens_data.alpha_run = alpha_start.t();
-  dens_data.shape = 0.0;
-  dens_data.rate = 0.0;
+  dens_data.shape_Valpha = 0.0;
+  dens_data.rate_Valpha = 0.0;
   // lambda 
   dens_data.pos_lambda = 0;
   dens_data.sp_lambda = 0;
