@@ -1,4 +1,4 @@
-context("test-jSDM_binomial_probit")
+#context("test-jSDM_binomial_probit")
 #== Without traits ======
 #===== Simple species distribution model (SDM) ==========
 
@@ -202,7 +202,6 @@ mod <- jSDM::jSDM_binomial_probit(burnin=burnin, mcmc=mcmc, thin=thin,
                                   site_data = X, site_effect="fixed",
                                   alpha_start=0, beta_start=0,
                                   V_alpha=10,
-                                  shape=0.5, rate=0.0005,
                                   mu_beta=0, V_beta=10,
                                   seed=1234, verbose=1)
 # Tests
@@ -254,7 +253,7 @@ mod <- jSDM::jSDM_binomial_probit(burnin=burnin, mcmc=mcmc, thin=thin,
                                   site_data = X, site_effect="random",
                                   alpha_start=0, beta_start=0,
                                   V_alpha=1,
-                                  shape=0.5, rate=0.0005,
+                                  shape_Valpha=0.5, rate_Valpha=0.0005,
                                   mu_beta=0, V_beta=10,
                                   seed=1234, verbose=1)
 # Tests
@@ -317,7 +316,6 @@ mod <- jSDM::jSDM_binomial_probit(presence_data=Y,
                                   alpha_start=0, beta_start=0,
                                   lambda_start=0, W_start=0,
                                   V_alpha=10,
-                                  shape=0.5, rate=0.0005,
                                   mu_beta=0, V_beta=10,
                                   mu_lambda=0, V_lambda=1,
                                   seed=1234, verbose=1)
@@ -383,7 +381,7 @@ mod <- jSDM::jSDM_binomial_probit(presence_data=Y,
                                   alpha_start=0, beta_start=0,
                                   lambda_start=0, W_start=0,
                                   V_alpha=1,
-                                  shape=0.5, rate=0.0005,
+                                  shape_Valpha=0.5, rate_Valpha=0.0005,
                                   mu_beta=0, V_beta=10,
                                   mu_lambda=0, V_lambda=1,
                                   seed=1234, verbose=1)
@@ -449,7 +447,7 @@ mod <- jSDM::jSDM_binomial_probit(presence_data=Y,
                                   alpha_start=0, beta_start=0,
                                   lambda_start=0, W_start=0,
                                   V_alpha=1,
-                                  shape=0.5, rate=0.0005,
+                                  shape_Valpha=0.5, rate_Valpha=0.0005,
                                   mu_beta=0, V_beta=10,
                                   mu_lambda=0, V_lambda=1,
                                   seed=1234, verbose=1)
@@ -727,7 +725,6 @@ mod <- jSDM::jSDM_binomial_probit(burnin=burnin, mcmc=mcmc, thin=thin,
                                   mu_gamma=0, V_gamma=10,
                                   alpha_start=0, beta_start=0,
                                   V_alpha=10,
-                                  shape=0.5, rate=0.0005,
                                   mu_beta=0, V_beta=10,
                                   seed=1234, verbose=1)
 # Tests
@@ -801,7 +798,8 @@ mod <- jSDM::jSDM_binomial_probit(burnin=burnin, mcmc=mcmc, thin=thin,
                                   mu_gamma=0, V_gamma=10,
                                   alpha_start=0, beta_start=0,
                                   V_alpha=1,
-                                  shape=0.5, rate=0.0005,
+                                  shape_Valpha=0.5,
+                                  rate_Valpha=0.0005,
                                   mu_beta=0, V_beta=10,
                                   seed=1234, verbose=1)
 # Tests
@@ -886,7 +884,7 @@ mod <- jSDM::jSDM_binomial_probit(burnin=burnin, mcmc=mcmc, thin=thin,
                                   alpha_start=0, beta_start=0,
                                   lambda_start=0, W_start=0,
                                   V_alpha=10,
-                                  shape=0.5, rate=0.0005,
+                                  shape_Valpha=0.5, rate_Valpha=0.0005,
                                   mu_beta=0, V_beta=10,
                                   mu_lambda=0, V_lambda=1,
                                   seed=1234, verbose=1)
@@ -974,7 +972,7 @@ mod <- jSDM::jSDM_binomial_probit(presence_data=Y,
                                   alpha_start=0, beta_start=0,
                                   lambda_start=0, W_start=0,
                                   V_alpha=1,
-                                  shape=0.5, rate=0.0005,
+                                  shape_Valpha=0.5, rate_Valpha=0.0005,
                                   mu_beta=0, V_beta=10,
                                   mu_lambda=0, V_lambda=1,
                                   seed=1234, verbose=1)
@@ -1060,7 +1058,7 @@ mod <- jSDM::jSDM_binomial_probit(presence_data=Y,
                                   alpha_start=0, beta_start=0,
                                   lambda_start=0, W_start=0,
                                   V_alpha=1,
-                                  shape=0.5, rate=0.0005,
+                                  shape_Valpha=0.5, rate_Valpha=0.0005,
                                   mu_beta=0, V_beta=10,
                                   mu_lambda=0, V_lambda=1,
                                   seed=1234, verbose=1)
@@ -1151,7 +1149,7 @@ mod <- jSDM::jSDM_binomial_probit(presence_data=Y,
                                   alpha_start=0, beta_start=0,
                                   lambda_start=0, W_start=0,
                                   V_alpha=1,
-                                  shape=0.5, rate=0.0005,
+                                  shape_Valpha=0.5, rate_Valpha=0.0005,
                                   mu_beta=0, V_beta=1,
                                   mu_lambda=0, V_lambda=1,
                                   seed=1234, verbose=1)
@@ -1237,7 +1235,7 @@ mod <- jSDM::jSDM_binomial_probit(presence_data=Y,
                                   alpha_start=0, beta_start=0,
                                   lambda_start=0, W_start=0,
                                   V_alpha=1,
-                                  shape=0.5, rate=0.0005,
+                                  shape_Valpha=0.5, rate_Valpha=0.0005,
                                   mu_beta=0, V_beta=1,
                                   mu_lambda=0, V_lambda=1,
                                   seed=1234, verbose=1)
