@@ -1,4 +1,4 @@
-context("test-jSDM_binomial_probit_long_format")
+#context("test-jSDM_binomial_probit_long_format")
 
 #=== Without traits =======
 
@@ -263,7 +263,7 @@ mod <- jSDM::jSDM_binomial_probit_long_format(burnin=burnin, mcmc=mcmc, thin=thi
                                               site_effect="fixed",
                                               alpha_start=0, beta_start=0,
                                               V_alpha=10,
-                                              shape=0.5, rate=0.0005,
+                                              shape_Valpha=0.5, rate_Valpha=0.0005,
                                               mu_beta=0, V_beta=100,
                                               seed=1234, verbose=1)
 # Tests
@@ -328,7 +328,7 @@ mod <- jSDM::jSDM_binomial_probit_long_format(burnin=burnin, mcmc=mcmc, thin=thi
                                               site_effect="random",
                                               alpha_start=0, beta_start=0,
                                               V_alpha=1,
-                                              shape=0.5, rate=0.0005,
+                                              shape_Valpha=0.5, rate_Valpha=0.0005,
                                               mu_beta=0, V_beta=100,
                                               seed=1234, verbose=1)
 # Tests
@@ -404,7 +404,7 @@ mod <- jSDM::jSDM_binomial_probit_long_format(data=data,
                                               alpha_start=0, beta_start=0,
                                               lambda_start=0, W_start=0,
                                               V_alpha=10,
-                                              shape=0.5, rate=0.0005,
+                                              shape_Valpha=0.5, rate_Valpha=0.0005,
                                               mu_beta=0, V_beta=100,
                                               mu_lambda=0, V_lambda=10,
                                               seed=1234, verbose=1)
@@ -485,7 +485,7 @@ mod <- jSDM::jSDM_binomial_probit_long_format(data=data,
                                               alpha_start=0, beta_start=0,
                                               lambda_start=0, W_start=0,
                                               V_alpha=1,
-                                              shape=0.5, rate=0.0005,
+                                              shape_Valpha=0.5, rate_Valpha=0.0005,
                                               mu_beta=0, V_beta=100,
                                               mu_lambda=0, V_lambda=10,
                                               seed=1234, verbose=1)
@@ -558,7 +558,7 @@ mod <- jSDM::jSDM_binomial_probit_long_format(data=data,
                                               alpha_start=0, beta_start=0,
                                               lambda_start=0, W_start=0,
                                               V_alpha=1,
-                                              shape=0.5, rate=0.0005,
+                                              shape_Valpha=0.5, rate_Valpha=0.0005,
                                               mu_beta=0, V_beta=100,
                                               mu_lambda=0, V_lambda=10,
                                               seed=1234, verbose=1)
@@ -906,7 +906,7 @@ mod <- jSDM::jSDM_binomial_probit_long_format(burnin=burnin, mcmc=mcmc, thin=thi
                                               alpha_start=0, gamma_start=0,
                                               beta_start=0,
                                               V_alpha=10,
-                                              shape=0.5, rate=0.0005,
+                                              shape_Valpha=0.5, rate_Valpha=0.0005,
                                               mu_gamma=0, V_gamma=100,
                                               mu_beta=0, V_beta=100,
                                               seed=1234, verbose=1)
@@ -988,7 +988,7 @@ mod <- jSDM::jSDM_binomial_probit_long_format(burnin=burnin, mcmc=mcmc, thin=thi
                                               site_effect="random",
                                               alpha_start=0, gamma_start=0,
                                               V_alpha=1, beta_start=0,
-                                              shape=0.5, rate=0.0005,
+                                              shape_Valpha=0.5, rate_Valpha=0.0005,
                                               mu_gamma=0, V_gamma=100,
                                               mu_beta=0, V_beta=100,
                                               seed=1234, verbose=1)
@@ -1082,7 +1082,7 @@ mod <- jSDM::jSDM_binomial_probit_long_format(data=data,
                                               beta_start=0,
                                               lambda_start=0, W_start=0,
                                               V_alpha=10,
-                                              shape=0.5, rate=0.0005,
+                                              shape_Valpha=0.5, rate_Valpha=0.0005,
                                               mu_gamma=0, V_gamma=100,
                                               mu_beta=0, V_beta=100,
                                               mu_lambda=0, V_lambda=10,
@@ -1181,7 +1181,7 @@ mod <- jSDM::jSDM_binomial_probit_long_format(data=data,
                                               beta_start=0,
                                               lambda_start=0, W_start=0,
                                               V_alpha=1,
-                                              shape=0.5, rate=0.0005,
+                                              shape_Valpha=0.5, rate_Valpha=0.0005,
                                               mu_gamma=0, V_gamma=100,
                                               mu_beta=0, V_beta=100,
                                               mu_lambda=0, V_lambda=10,
@@ -1279,13 +1279,13 @@ mod <- jSDM::jSDM_binomial_probit_long_format(data=data,
                                               beta_start=0,
                                               lambda_start=0, W_start=0,
                                               V_alpha=1,
-                                              shape=0.5, rate=0.0005,
+                                              shape_Valpha=0.5, rate_Valpha=0.0005,
                                               mu_gamma=0, V_gamma=100,
                                               mu_beta=0, V_beta=100,
                                               mu_lambda=0, V_lambda=10,
                                               seed=1234, verbose=1)
 # Tests
-test_that("jSDM_binomial_probit_long_format works with random site effect and latent variables", {
+test_that("jSDM_binomial_probit_long_format works with intercept only, random site effect and latent variables", {
   expect_equal(length(mod$mcmc.sp),nsp)
   expect_equal(dim(mod$mcmc.sp[["sp_1"]]),c(nsamp,ncol(X)+n_latent))
   expect_equal(dim(mod$mcmc.gamma),c(nsamp,ncol(D)))
