@@ -1,4 +1,4 @@
-context("test-jSDM_binomial_probit_sp_constrained")
+#context("test-jSDM_binomial_probit_sp_constrained")
 #== Without traits ======
 #======== Joint species distribution model (JSDM) ====================
 #============= JSDM with latent variables ===============
@@ -114,7 +114,6 @@ mod <- jSDM::jSDM_binomial_probit_sp_constrained(presence_data=Y,
                                                  alpha_start=0, beta_start=0,
                                                  lambda_start=0, W_start=0,
                                                  V_alpha=10,
-                                                 shape=0.5, rate=0.0005,
                                                  mu_beta=0, V_beta=10,
                                                  mu_lambda=0, V_lambda=1,
                                                  verbose=1)
@@ -182,7 +181,7 @@ mod <- jSDM::jSDM_binomial_probit_sp_constrained(presence_data=Y,
                                                  alpha_start=0, beta_start=0,
                                                  lambda_start=0, W_start=0,
                                                  V_alpha=1,
-                                                 shape=0.5, rate=0.0005,
+                                                 shape_Valpha=0.5, rate_Valpha=0.0005,
                                                  mu_beta=0, V_beta=10,
                                                  mu_lambda=0, V_lambda=1,
                                                  verbose=1)
@@ -250,7 +249,7 @@ mod <- jSDM::jSDM_binomial_probit_sp_constrained(presence_data=Y,
                                                  alpha_start=0, beta_start=0,
                                                  lambda_start=0, W_start=0,
                                                  V_alpha=1,
-                                                 shape=0.5, rate=0.0005,
+                                                 shape_Valpha=0.5, rate_Valpha=0.0005,
                                                  mu_beta=0, V_beta=10,
                                                  mu_lambda=0, V_lambda=1,
                                                  verbose=1)
@@ -512,7 +511,6 @@ mod <- jSDM::jSDM_binomial_probit_sp_constrained(burnin=burnin, mcmc=mcmc, thin=
                                                  alpha_start=0, beta_start=0,
                                                  lambda_start=0, W_start=0,
                                                  V_alpha=10,
-                                                 shape=0.5, rate=0.0005,
                                                  mu_beta=0, V_beta=10,
                                                  mu_lambda=0, V_lambda=1,
                                                  verbose=1)
@@ -602,7 +600,7 @@ mod <- jSDM::jSDM_binomial_probit_sp_constrained(presence_data=Y,
                                                  alpha_start=0, beta_start=0,
                                                  lambda_start=0, W_start=0,
                                                  V_alpha=1,
-                                                 shape=0.5, rate=0.0005,
+                                                 shape_Valpha=0.5, rate_Valpha=0.0005,
                                                  mu_beta=0, V_beta=10,
                                                  mu_lambda=0, V_lambda=1,
                                                  verbose=1)
@@ -690,7 +688,7 @@ mod <- jSDM::jSDM_binomial_probit_sp_constrained(presence_data=Y,
                                                  alpha_start=0, beta_start=0,
                                                  lambda_start=0, W_start=0,
                                                  V_alpha=1,
-                                                 shape=0.5, rate=0.0005,
+                                                 shape_Valpha=0.5, rate_Valpha=0.0005,
                                                  mu_beta=0, V_beta=10,
                                                  mu_lambda=0, V_lambda=1,
                                                  verbose=1)
@@ -783,7 +781,7 @@ mod <- jSDM::jSDM_binomial_probit_sp_constrained(presence_data=Y,
                                                  alpha_start=0, beta_start=0,
                                                  lambda_start=0, W_start=0,
                                                  V_alpha=1,
-                                                 shape=0.5, rate=0.0005,
+                                                 shape_Valpha=0.5, rate_Valpha=0.0005,
                                                  mu_beta=0, V_beta=1,
                                                  mu_lambda=0, V_lambda=1,
                                                  verbose=1)
@@ -871,7 +869,7 @@ mod <- jSDM::jSDM_binomial_probit_sp_constrained(presence_data=Y,
                                                  alpha_start=0, beta_start=0,
                                                  lambda_start=0, W_start=0,
                                                  V_alpha=1,
-                                                 shape=0.5, rate=0.0005,
+                                                 shape_Valpha=0.5, rate_Valpha=0.0005,
                                                  mu_beta=0, V_beta=1,
                                                  mu_lambda=0, V_lambda=1,
                                                  verbose=1)
